# -*- coding: utf-8 -*-

from odoo import _, api, fields, models


class OpenerpEnterpriseExistingSubscription(models.TransientModel):

    _name = 'openerp.enterprise.existing_subscription'
    _description = 'An existing subscription has been found'

    new_subscription_id = fields.Many2one('sale.order', string='Origin Quotation')
    existing_subscription_id = fields.Many2one('sale.order', string='Existing Subscription')
    message = fields.Char('Warning Message', compute='_compute_message')
    state = fields.Selection([('confirm', 'Confirm'), ('renew', 'Renew')], default='confirm')

    @api.depends('existing_subscription_id')
    def _compute_message(self):
        for wizard in self:
            if wizard.state == "confirm":
                wizard.message = _(
                    'Are you sure you want to confirm this quote.'
                    'This customer has already a subscription %s. '
                    'Are you sure you do not want to renew '
                    'this order?') % wizard.existing_subscription_id.display_name
            elif wizard.state == "renew":
                if wizard.existing_subscription_id:
                    wizard.message = _(
                        'This order has not started yet. If you want to renew it, '
                        'cancel this order and renew from the '
                        'parent %s.') % wizard.existing_subscription_id.display_name
                else:
                    wizard.message = _(
                        'This order has not started yet. If you want '
                        'to create a new order, cancel this one first.')

    def go_to_existing(self):
        action = {
            'name': 'Subscriptions',
            'res_model': 'sale.order',
            'views': [[self.env.ref('sale_subscription.sale_subscription_primary_form_view').id, "form"]],
            'res_id': self.existing_subscription_id.id,
            'search_view_id': self.env.ref('sale_subscription.sale_subscription_view_search').id,
            'type': 'ir.actions.act_window',
        }

        return action

    def cancel_and_create(self):
        self.new_subscription_id._action_cancel()
        action = {
            'name': 'Subscriptions',
            'res_model': 'sale.order',
            'views': [[self.env.ref('sale_subscription.sale_subscription_primary_form_view').id, "form"]],
            'search_view_id': self.env.ref('sale_subscription.sale_subscription_view_search').id,
            'type': 'ir.actions.act_window',
        }

        return action

    def cancel_and_go_to_existing(self):
        self.new_subscription_id._action_cancel()
        action = {
            'name': 'Subscriptions',
            'res_model': 'sale.order',
            'views': [[self.env.ref('sale_subscription.sale_subscription_primary_form_view').id, "form"]],
            'res_id': self.existing_subscription_id.id,
            'search_view_id': self.env.ref('sale_subscription.sale_subscription_view_search').id,
            'type': 'ir.actions.act_window',
        }

        return action

    def confirm_new(self):
        return self.new_subscription_id.with_context(check_existing_sub=False).action_confirm()
